// File created by
// Lung Razvan <long1eu>
// on 2019-07-05

import 'dart:async';
import 'dart:convert';
import 'dart:io';

import 'package:args/args.dart';
import 'package:i18n_generator/flutter_module.dart';
import 'package:path/path.dart';

import 'commands.dart';

Future<void> build(ArgResults result) async {
  final String source = canonicalize(absolute(result[sourceKey]));
  final String output = canonicalize(absolute(result[outputKey]));
  final bool watch = result[watchKey];
  final bool createPaths = result[createPathsKey];

  final Directory sourceDir = Directory(source);
  final Directory outputDir = Directory(output);

  if (createPaths) {
    if (!sourceDir.existsSync()) {
      sourceDir.createSync(recursive: true);
    }

    if (!outputDir.existsSync()) {
      outputDir.createSync(recursive: true);
    }
  }

  final FlutterModule module = FlutterModule(sourceDir, outputDir);
  module.init();
  module.createFiles();

  if (watch) {
    final Completer<void> completer = Completer<void>();
    final StreamSubscription<String> sub = stdin //
        .transform(utf8.decoder)
        .transform(const LineSplitter())
        .listen((String args) => args == 'x' ? completer.complete() : null);

    module.watch;
    await completer.future;

    sub.cancel();
  }

  module.dispose();
}
