// File created by
// Lung Razvan <long1eu>
// on 2019-07-05

import 'dart:io';

import 'package:args/args.dart';

const String sourceKey = 'source';
const String sourceDefault = './res';

const String outputKey = 'output';
const String outputDefault = './lib/src/generated';

const String watchKey = 'watch';
const bool watchDefault = false;

const String createPathsKey = 'create-paths';
const bool createPathsKeyDefault = true;

const String portKey = 'port';
const String portDefault = '45877';

ArgParser get parser {
  return ArgParser() //
    ..addCommand('build', _buildParser)
    ..addCommand('socket', _socket)
    ..addCommand('help');
}

ArgParser get _buildParser {
  return ArgParser()
    ..addOption(
      sourceKey,
      abbr: 's',
      help: 'Specify where to search for the arb files.',
      valueHelp: sourceDefault,
      defaultsTo: sourceDefault,
    )
    ..addOption(
      outputKey,
      abbr: 'o',
      help: 'Specify where to save the generated dart files.',
      valueHelp: outputDefault,
      defaultsTo: outputDefault,
    )
    ..addFlag(
      watchKey,
      abbr: 'w',
      help: 'Whether you want to listen for file changes.\n'
          'NOTE: Keep in mind that the changes are detected when the file is\n'
          'saved after modification. So if you use an IDE make sure to save\n'
          'the arb file so that the dart files are updated.',
      defaultsTo: watchDefault,
    )
    ..addFlag(
      'create-paths',
      abbr: 'c',
      help: 'This will create the folders structure recursively.',
      defaultsTo: createPathsKeyDefault,
    );
}

ArgParser get _socket {
  return ArgParser()
    ..addOption(
      portKey,
      abbr: 'p',
      help: 'Specify the port you want to open the socket to.',
      valueHelp: portDefault,
      defaultsTo: portDefault,
    );
}

void printUsage() {
  for (String command in parser.commands.keys) {
    final ArgParser options = parser.commands[command];

    stdout //
      ..writeln('$command')
      ..writeln(options.usage)
      ..writeln();
  }
}
