// File created by
// Lung Razvan <long1eu>
// on 2019-07-05

import 'dart:async';
import 'dart:convert';
import 'dart:io';

import 'package:args/args.dart';
import 'package:shelf/shelf.dart' as shelf;
import 'package:shelf/shelf_io.dart' as io;

import 'commands.dart';

Completer<int> exitCompleter = Completer<int>();

Future<void> socket(ArgResults results) async {
  final int port = int.tryParse(results[portKey]) ?? portDefault;

  if (port == null) {
    stdout.writeln('Could not parse port value "${results[portKey]}" into a number.');
    exit(64);
    return;
  }

  final shelf.Handler handler = const shelf.Pipeline().addMiddleware(shelf.logRequests()).addHandler(_handleRequest);

  final HttpServer server = await io.serve(
    handler,
    InternetAddress.loopbackIPv4,
    port,
    securityContext: SecurityContext.defaultContext,
  );

  print('Serving at https://${server.address.host}:${server.port}.');

  final int exitCode = await exitCompleter.future;
  await server.close();
  exit(exitCode);
}

Future<shelf.Response> _handleRequest(shelf.Request request) async {
  switch (request.method) {
    case 'POST':
      if (request.url.path == 'echo') {
        return shelf.Response(200, body: request.read());
      }

      break;
    case 'OPTIONS':
      if (request.headers['option'] == 'close') {
        exitCompleter.complete(0);
        return shelf.Response(200, body: 'Close successfuly.');
      }

      break;
    default:
      return shelf.Response(200, body: jsonEncode(<String, String>{'message': 'All good.'}));
  }

  return shelf.Response(200, body: jsonEncode(<String, String>{'message': 'All good.'}));
}
